@@ -4,9 +4,10 @@ Created on 27/06/2014
 @author: Carlo Pires <carlopires@gmail.com>
 """
 import sys, types, inspect, functools
+from functools import lru_cache
 from importlib import import_module
 
-__version__ = 1.6
+__version__ = 1.7
 
 class TypeCheckError(Exception): 
     pass
@@ -18,6 +19,11 @@ def _caller():
     #caller_annotations = ???
     return caller_name, caller_args
 
+@lru_cache(maxsize=None)
+def _cached_import(obj):
+    pkg, cls = obj.rsplit('.', 1)
+    return getattr(import_module(pkg), cls)
+
 NoType = object()
 NoneType = type(None)
 NotImplementedType = type(NotImplemented)
@@ -32,8 +38,7 @@ def _resolve_type(obj):
     elif obj.__class__ is tuple:
         return tuple([_resolve_type(t) for t in obj])
     elif obj.__class__ is str and '.' in obj:
-        pkg, cls = obj.rsplit('.', 1)
-        return getattr(import_module(pkg), cls)
+        return _cached_import(obj)
     else:
         return obj
 
